/**singing_game.h is part of JamMo.
License: GPLv2, read more from COPYING

This file is for clutter based gui.
*/
#ifndef _SINGING_GAME_H_
#define _SINGING_GAME_H_

void start_mobikid_play_recorded();
void start_mobikid_recording();
void start_mobikid_play_recorded();
void start_mobikid_selection();

void init_singing_game();
gboolean singing_game_is_initialized();

#endif /* SINGING_GAME_H */
